# New in 0.15.2 (2022-03-15)

## Changes

-   Remove setuptools pinned requirement due to new PyTorch 1.11 fix ([#1436]).
-   Switch to myst-parsed markdown for docs ([#1435]).
-   Add `prepare_query_data(adata, reference_model)` to {class}`~scvi.model.base.ArchesMixin` to enable query data cleaning prior to reference mapping ([#1441]).
-   Add Human Lung Cell Atlas tutorial ([#1442]).

## Bug fixes

-   Errors when arbitrary kwargs are passed into `setup_anndata()` ([#1439]).
-   Fix {class}`scvi.external.SOLO` to use `train_size=0.9` by default, which enables early stopping to work properly ([#1438]).
-   Fix scArches version warning ([#1431]).
-   Fix backwards compat for {class}`~scvi.model.SCANVI` loading ([#1441]).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]
-   [@grst]

[#1442]: https://github.com/YosefLab/scvi-tools/pull/1442
[#1441]: https://github.com/YosefLab/scvi-tools/pull/1441
[#1439]: https://github.com/YosefLab/scvi-tools/pull/1439
[#1438]: https://github.com/YosefLab/scvi-tools/pull/1438
[#1436]: https://github.com/YosefLab/scvi-tools/pull/1436
[#1435]: https://github.com/YosefLab/scvi-tools/pull/1435
[#1431]: https://github.com/YosefLab/scvi-tools/pull/1431
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@grst]: https://github.com/grst
